import streamlit as st
from queries import find_devices
from devices import Device

# Eine Überschrift der ersten Ebene
st.write("# Gerätemanagement")

# Eine Überschrift der zweiten Ebene
st.write("## Geräteauswahl")

# Eine Auswahlbox mit Datenbankabfrage, das Ergebnis wird in current_device gespeichert
device_names_in_db = find_devices()

if not device_names_in_db:
    st.write("No devices found.")
    st.stop()

current_device_name = st.selectbox(
    'Gerät auswählen',
    options=device_names_in_db, key="sbDevice")

if current_device_name not in device_names_in_db:
    st.error("Selected device is not in the database.")
    st.stop()

loaded_device = Device.find_by_attribute("device_name", current_device_name)
if not loaded_device:
    st.error("Device not found in the database.")
    st.stop()

st.write(f"Loaded Device: {loaded_device}")

with st.form("Device"):
    st.write(loaded_device.device_name)

    text_input_val = st.text_input("Geräte-Verantwortlicher", value=loaded_device.managed_by_user_id)
    loaded_device.set_managed_by_user_id(text_input_val)

    # Every form must have a submit button.
    submitted = st.form_submit_button("Submit")
    if submitted:
        loaded_device.store_data()
        st.write("Data stored.")
        st.rerun()

st.write("Session State:")
st.session_state